@@ -92,7 +92,8 @@ EVENT_ALIASES = {
     "email": "ses",
     "entitlement.marketplace": "marketplace-entitlement-service",
     "es": "elasticsearch-service",
-    "events": "cloudwatch-events",
+    "events": "eventbridge",
+    "cloudwatch-events": "eventbridge",
     "iot-data": "iot-data-plane",
     "iot-jobs-data": "iot-jobs-data-plane",
     "iot1click-devices": "iot-1click-devices-service",
@@ -1312,9 +1313,11 @@ class ContainerMetadataFetcher(object):
             try:
                 return json.loads(response_text)
             except ValueError:
-                raise MetadataRetrievalError(
-                    error_msg=("Unable to parse JSON returned from "
-                               "ECS metadata: %s" % response_text))
+                error_msg = (
+                    "Unable to parse JSON returned from ECS metadata services"
+                )
+                logger.debug('%s:%s', error_msg, response_text)
+                raise MetadataRetrievalError(error_msg=error_msg)
         except RETRYABLE_HTTP_ERRORS as e:
             error_msg = ("Received error when attempting to retrieve "
                          "ECS metadata: %s" % e)
